Daemon rucio-hermes — Rucio 1.2 documentation

# Daemon rucio-hermes

    usage: rucio-hermes [-h] [--run-once] [--threads THREADS] [--bulk BULK]
                        [--delay DELAY] [--broker-timeout BROKER_TIMEOUT]
                        [--broker-retry BROKER_RETRY]

## Named Arguments

`--run-once` | One iteration only Default: False
`--threads` | Concurrency control: number of threads Default: 1
`--bulk` | Bulk control: number of requests per cycle Default: 1000
`--delay` | Delay control: second control per cycle Default: 10
`--broker-timeout`
| Broker control: timeout second per cycle Default: 3
`--broker-retry` | Broker control: number of retries per cycle Default: 3